---
slug: /error-code-5000-5999
---

# 5000 ~ 5999

This range represents SQL layer error codes. It includes SQL error codes, WITH clause error codes, and Factoring error codes.

## ERROR 5002 (HY000) : Resolve error

* seekdb error code: 5002

* Error reason: A parsing error occurred.

* Solution: Contact technical support.

## ERROR 5010 (21000) : Unknown operator

* seekdb error code: 5010

* Error reason: An internal defense check error occurred during parsing.

* Solution: Contact technical support.

## ERROR 5011 (42000) : Duplicated star

* seekdb error code: 5011

* Error reason: The use of `*` is incorrect. Only one `*` is supported in an SQL statement.

* Solution: Remove the extra `*` from the SQL statement.

## ERROR 5012 (HY000) : Illegal ID

* seekdb error code: 5012

* Error reason: An internal parameter defense error occurred.

* Solution: Contact technical support.

## ERROR 5014 (HY000) : Illegal value

* seekdb error code: 5014

* Error reason: A numeric type conversion error occurred.

* Solution: Check whether the CAST statement in the SQL statement is correct, for example, whether an implicit conversion exists.

## ERROR 5016 (HY000) : Generate logical plan error

* seekdb error code: 5016

* Error reason: An error occurred when generating a plan.

* Solution: Contact technical support.

## ERROR 5017 (HY000) : Schema not set

* seekdb error code: 5017

* Error reason: An internal error occurred.

* Solution: Contact technical support.

## ERROR 5023 (S1004) : unsupport MySQL type (number). Maybe you should use java.sql.Timestamp instead of java.util.Date

* seekdb error code: 5023

* Error reason: The type is not supported.

* Solution: Contact technical support.

## ERROR 5031 (HY000) : Column not found

* seekdb error code: 5031

* Error reason: The column does not exist.

* Solution: Check whether the column involved in the operation exists, or contact technical support.

## ERROR 5034 (01007) : No user

* seekdb error code: 5034

* Error reason: The username is empty.

* Solution: Provide the username.

## ERROR 5050 (42710) : User exists

* seekdb error code: 5050

* Error reason: The user or role already exists.

* Solution: Check whether the user or role exists, or contact technical support.

## ERROR 5053 (HY093) : Incorrect arguments number to EXECUTE, need %ld arguments but give %ld

* seekdb error code: 5053

* Error reason: The number of bound variables in the EXECUTE statement is different from the number of parameters in the PREPARE statement.

* Solution: Ensure that the number of bound variables in the EXECUTE statement is the same as the number of parameters required in the PREPARE statement.

## ERROR 5058 (42000) : Duplicated parameters

* seekdb error code: 5058

* Error reason: Duplicate parameters.

* Solution: Contact technical support.

## ERROR 5063 (42000) : Unknown hint

* seekdb error code: 5063

* Error reason: A parsing error occurred.

* Solution: Contact technical support.

## ERROR 5066 (HY000) : Session interrupted

* seekdb error code: 5066

* Error reason: The session was terminated.

* Solution: Contact the system administrator or database administrator.

## ERROR 5071 (42000) : Cannot alter index column

* seekdb error code: 5071

* Error reason: The index reference column was deleted.

* Solution: The index reference column cannot be deleted.

## ERROR 5074 (23000) : NOP cannot be used here

* seekdb error code: 5074

* Error reason: A kernel bug occurred.

* Solution: Contact technical support.

## ERROR 5081 (25000) : The server is read only now

* seekdb error code: 5081

* Error reason: The data being operated on is read-only.

* Solution: Check whether the data being operated on is read-only, or contact technical support.

## ERROR 5083 (22000) : invalid obj type for type promotion: left_type=%s right_type=%s

* seekdb error code: 5083

* Error reason: A type conversion error occurred.

* Solution: Contact technical support.

## ERROR 5084 (22000) : Can not cast varchar value to bool type

* seekdb error code: 5084

* Error reason: A type conversion error occurred.

* Solution: Contact technical support.

## ERROR 5085 (22000) : Not a number Can not cast varchar value to number type

* seekdb error code: 5085

* Error reason: A type conversion error occurred.

* Solution: Contact technical support.

## ERROR 5086 (22000) : Not timestamp Can not cast varchar value to timestamp type

* seekdb error code: 5086

* Error reason: A type conversion error occurred.

* Solution: Contact technical support.

## ERROR 5087 (22000) : Result value was out of range when cast to number

* seekdb error code: 5087

* Error reason: The value is out of range.

* Solution: Contact technical support.

## ERROR 5090 (22000) : Precision was out of range

* seekdb error code: 5090

* Error reason: The precision is out of range.

* Solution: Contact technical support.

## ERROR 5091 (22000) : Scale value was out of range

* seekdb error code: 5091

* Error reason: The precision is out of range.

* Solution: Contact technical support.

## ERROR 5092 (42000) : Unknown index

* seekdb error code: 5092

* Error reason: The index is unknown.

* Solution: Check whether the index is incorrectly used in the interface.

## ERROR 5098 (22001) : Data too long(%d\>%ld) for column '%s'

* seekdb error code: 5098

* Error reason: The input number is out of range.

* Solution: Reduce the length of the number.

## ERROR 5099 (42000) : System config unknown

* seekdb error code: 5099

* Error reason: The configuration item is invalid.

* Solution: Check whether the configuration item name is correct.

## ERROR 5106 (42000) : EXTRACT() expected timestamp or a string as date argument

* seekdb error code: 5106

* Error reason: The data type is incorrect.

* Solution: Contact technical support.

## ERROR 5107 (42000) : Invalid operand type for IS operator, lval=%s

* seekdb error code: 5107

* Error reason: The `IS` expression has invalid parameters.

* Solution: Contact technical support.

## ERROR 5108 (42000) : function LENGTH（) expected a varchar argument

* seekdb error code: 5108

* Error reason: The `LENGTH` expression has invalid parameters.

* Solution: Contact technical support.

## ERROR 5110 (42000) : TIME_TO_USEC() expected timestamp or a string as date argument

* seekdb error code: 5110

* Error reason: The parameter of the `TIME_TO_USEC` function must be of the `VARCHAR` , `TIME` , `DATATIME` , or `TIMESTAMP` type.

* Solution: Change the type of the parameter.

## ERROR 5111 (42000) : USEC_TO_TIME expected a interger number as usec argument

* seekdb error code: 5111

* Error reason: The parameter of the `USEC_TO_TIME` function must be of the `TINYINT` , `MEDIUMINT` , `INT` , or `BIGINT` type.

* Solution: Change the type of the parameter.

## ERROR 5112 (42P01) : Variable %.\*s does not exists

* seekdb error code: 5112

* Error reason: The variable does not exist.

* Solution: Check whether the variable is misspelled.

## ERROR 5114 (42000) : Invalid numeric char '%c'

* seekdb error code: 5114

* Error reason: The parameter is not a valid number.

* Solution: Contact technical support.

## ERROR 5116 (HY000) : Logical operator child index overflow

* seekdb error code: 5116

* Error reason: A kernel error occurred.

* Solution: Contact technical support.

## ERROR 5117 (HY000) : fail to explain plan

* seekdb error code: 5117

* Error reason: An error occurred while generating the plan.

* Solution: Contact technical support.

## ERROR 5118 (HY000) : fail to copy logical operator

* seekdb error code: 5118

* Error reason: An error occurred while generating the plan.

* Solution: Contact technical support.

## ERROR 5119 (HY000) : fail to generate plan

* seekdb error code: 5119

* Error reason: An error occurred while generating the plan.

* Solution: Contact technical support.

## ERROR 5120 (HY000) : fail to create raw expr

* seekdb error code: 5120

* Error reason: An error occurred while generating the plan.

* Solution: Contact technical support.

## ERROR 5121 (HY000) : fail to generate join order

* seekdb error code: 5121

* Error reason: An error occurred while generating the plan.

* Solution: Contact technical support.

## ERROR 5122 (HY000) : optimizer general error

* seekdb error code: 5122

* Error reason: An error occurred while generating the plan.

* Solution: Contact technical support.

## ERROR 5130 (HY000) : sql resolver no memory

* seekdb error code: 5130

* Error reason: Insufficient memory.

* Solution: Increase the SQL memory or contact technical support.

## ERROR 5131 (HY000) : plan cache support dml only

* seekdb error code: 5131

* Error reason: The `OUTLINE` binding was applied to a non-DML statement.

* Solution: Do not apply the `OUTLINE` binding to non-DML statements.

## ERROR 5133 (42000) : No such grant defined

* seekdb error code: 5133

* Error reason: The privilege was not granted when it was revoked.

## ERROR 5136 (HY000) : plan exists in plan cache already

* seekdb error code: 5136

* Error reason: The plan already exists in the plan cache when it was added.

* Solution: This is an internal error code. Contact technical support.

## ERROR 5137 (HY000) : plan is expired

* seekdb error code: 5137

* Error reason: The plan has expired.

* Solution: This is an internal error code. Contact technical support.

## ERROR 5138 (HY000) : no plan exist

* seekdb error code: 5138

* Error reason: The plan does not exist when it is retrieved.

* Solution: This is an internal error code. Contact technical support.

## ERROR 5144 (HY000) : COLLATION '%.\*s' is notvalid for CHARACTER SET '%.\*s'

* seekdb error code: 5144

* Error reason: One of the following conditions occurred:

  * The string operands of an operator or built-in function (except for the `nlsparams` parameter) are not of the same character set.

  * The `nlsparams` operand is not of the database character set.

  * The string data passed to a built-in function is of a character set other than the database character set, but the built-in function does not support that character set.

  * The second parameter of `CHR()` or `CSCONVERT()` is not `CHAR_CS` or `NCHAR_CS`.

  * The character set of the string expression in the `VALUES` clause of the `INSERT` statement or the `SET` clause of the `UPDATE` statement is inconsistent with the character set of the column to which the string is inserted.

  * The character set of the value provided in the `DEFAULT` clause when the table is created is inconsistent with the character set declared for the column.

  * The parameters of the `PL/SQL` function do not meet the character set requirements of the corresponding parameters.

## ERROR 5212 (42000) : auto-increment column '%.\*s' should not be part of partition key

* seekdb error code: 5212

* Error reason: An auto-increment column cannot be part of the partition key.

* Solution: Remove the auto-increment column from the partition key.

## ERROR 5223 (42000) : wrong ident name

* seekdb error code: 5223

* Error reason: The variable name is invalid.

* Solution: Use a valid variable name.

## ERROR 5226 (42000) : plan cache memory used reach the high water mark

* seekdb error code: 5226

* Error reason: The plan cache has reached the memory upper limit, and the plan is automatically evicted.

* Solution: Increase the memory upper limit of the plan cache.

## ERROR 5234 (HY000) : The database \\'%.\*s\\' is read only so it cannot execute this statement

* seekdb error code: 5234

* Error reason: An operation was performed on a read-only database.

* Solution: Do not perform operations on a read-only database.

## ERROR 5235 (HY000) : The table \\'%.\*s.%.\*s\\' is read only so it cannot execute this statement

* seekdb error code: 5235

* Error reason: An operation was performed on a read-only table.

* Solution: Do not perform operations on read-only tables.

## ERROR 5243 (HY000) : system variables' version maybe different

* seekdb error code: 5243

* Error reason: Internal error code.

* Solution: Contact technical support for assistance.

## ERROR 5245 (HY000) : some tasks are skipped, skipped server addr is '%s', the orginal error code is %d

* seekdb error code: 5245

* Error reason: Internal error code.

* Solution: Contact technical support for assistance.

## ERROR 5248 (HY000) : Alter table add auto_increment column is dangerous, table_name=\\'%.\*s\\', column_name=\\'%s\\'

* seekdb error code: 5248

* Error reason: It is not recommended to add an auto-increment column when modifying a table.

* Solution: Perform this operation only when the table contains no data.

## ERROR 5252 (HY000) : Column \\'%.\*s\\' definition is ambiguous. Column has both NULL and NOT NULL attributes

* seekdb error code: 5252

* Error reason: The field is defined as both `NULL` and `NOT NULL`.

* Solution: Keep only one of the definitions.

## ERROR 5258 (HY000) : Invalid block size, block size should between 1024 and 1048576

* seekdb error code: 5258

* Error reason: The block size is invalid.

* Solution: Modify the block size.

## ERROR 5264 (HY000) : Outline '%.\*s' already exists

* seekdb error code: 5264

* Error reason: The `OUTLINE` already exists.

* Solution: Check whether the same `OUTLINE` is bound to other SQL statements.

## ERROR 5265 (HY000) : Outline \\'%.\*s.%.\*s\\' doesn\\'t exist

* seekdb error code: 5265

* Error reason: The `OUTLINE` does not exist.

* Solution: Check whether the `OUTLINE` is created.

## ERROR 5267 (HY000) : invalid outline ,error info:%s

* seekdb error code: 5267

* Error reason: The `OUTLINE` is invalid.

* Solution: Contact technical support for assistance.

## ERROR 5268 (HY000) : SQL reach max concurrent num %ld

* seekdb error code: 5268

* Error reason: The SQL query reaches the throttling limit.

* Solution: Reduce the concurrency.

## ERROR 5269 (HY000) : can not perform DDL/DML over objects in Recycle Bin

* seekdb error code: 5269

* Error reason: You cannot perform DDL or DML operations on objects in the recycle bin.

* Solution: Restore the objects from the recycle bin and then perform the operations.

## ERROR 5270 (HY000) : object not in RECYCLE BIN

* seekdb error code: 5270

* Error reason: The object is not in the recycle bin.

* Solution: Contact technical support for assistance.

## ERROR 5272 (HY000) : Outline content '%.\*s' of outline '%.\*s' already exists when added

* seekdb error code: 5272

* Error reason: The `OUTLINE` already exists.

* Solution: Check whether the previously created `OUTLINE` meets your requirements. If it does, do not create a new `OUTLINE`. If it does not, drop the existing `OUTLINE` and create a new one.

## ERROR 5273 (HY000) : Max concurrent in outline '%.\*s' already exists when added

* seekdb error code: 5273

* Error reason: The throttling rule to be created already exists.

* Solution: Check whether the throttling rule specified in the statement already exists.

## ERROR 5278 (HY000) : This partition value with incorrect charset type

* seekdb error code: 5278

* Error reason: The Meta information of the partition value is inconsistent.

* Solution: Modify the partition value to make the Meta information consistent.

## ERROR 5291 (HY000) : The CTXCAT column must be contiguous in the index column list

* seekdb error code: 5291

* Error reason: The `CTXCAT` field must be contiguous.

* Solution: Adjust the `CTXCAT` field, or contact technical support for assistance.

## ERROR 5297 (HY000) : unexpected time zone info transition

* seekdb error code: 5297

* Error reason: A gap or overlap time is used.

* Solution: Use a non-gap time or set the `error_on_overlap_time` variable to `false`.

## ERROR 5298 (HY000) : synonym '%.\*s' already exists

* seekdb error code: 5298

* Error reason: The synonym already exists.

* Solution: Check for conflicting synonym names and create synonyms with different names.

## ERROR 5299 (HY000) : synonym \\'%.\*s.%.\*s\\' doesn\\'t exist

* seekdb error code: 5299

* Error reason: The synonym does not exist.

* Solution: Check whether the synonym does not exist.

## ERROR 5300 (HY000) : missing ORDER BY expression in the window specification

* seekdb error code: 5300

* Error reason: The `ORDER BY` expression is missing in the window function.

* Solution: Add the relevant `ORDER BY` expression to the window function.

## ERROR 5301 (HY000) : The argument of the window function should be a constant for a partition

* seekdb error code: 5301

* Error reason: The parameter of the window function must be a constant.

* Solution: Modify the relevant parameter in the window function to a constant value.

## ERROR 5307 (HY000) : Not enough thread resource to execute the query. Require setting parallel_servers_target to a value no less than %ld for this query

* seekdb error code: 5307

* Error reason: The number of execution threads is insufficient.

* Solution: Increase the value of the `parallel_servers_target` system variable.

## ERROR 5309 (HY000) : Ignore sql in restore process

* seekdb error code: 5309

* Cause: Specific SQL statements need to be skipped during logical restore.

* Solution: No action is required.

## ERROR 5311 (HY000) : Invalid column id for %.\*s

* seekdb error code: 5311

* Cause: The `ID` column is invalid.

* Solution: Contact technical support for assistance.

## ERROR 5312 (HY000) : Duplicated ddl id '%.\*s'

* seekdb error code: 5312

* Cause: The `ID` column is duplicated.

* Solution: Contact technical support for assistance.

## ERROR 5319 (HY000) : Child column \\'%.\*s\\' data length cannot be less than parent column \\'%.\*s\\' data length

* seekdb error code: 5319

* Cause: The length of the foreign key column is less than the length of the referenced column.

* Solution: Adjust the length of the related columns.

## ERROR 5320 (HY000) : \\'%.\*s\\': used in a foreign key constraint

* seekdb error code: 5320

* Cause: The field is used in a foreign key constraint.

* Solution: You cannot modify this field.

## ERROR 5325 (HY000) : ORDER SIBLINGS BY clause not allowed here

* seekdb error code: 5325

* Cause: The `ORDER SIBLINGS BY` clause appears in an incorrect location.

* Solution: The `ORDER SIBLINGS BY` clause can only appear in hierarchical queries.

## ERROR 5326 (HY000) : when using SYS_CONNECT_BY_PATH function, cannot have separator as part of column value

* seekdb error code: 5326

* Cause: The `SYS_CONNECT_BY_PATH` function is used to separate column values, but the separator is included in the column values.

* Solution: Specify a different separator for the `SYS_CONNECT_BY_PATH` function. Make sure that the separator is not included in any column values, and then retry the operation.

## ERROR 5327 (HY000) : Database can not be specified in public synonym

* seekdb error code: 5327

* Cause: The DATABASE option is specified for a public synonym.

* Solution: Do not specify the DATABASE option for a public synonym.

## ERROR 5328 (HY000) : Looping chain of synonyms

* seekdb error code: 5328

* Cause: A synonym is created that forms a loop with other synonyms.

* Solution: Check the synonyms that form a loop and create synonyms with different names to break the loop.

## ERROR 5329 (HY000) : Cannot create a synonym with same name as object

* seekdb error code: 5329

* Cause: The synonym has the same name as the object.

* Solution: Create a synonym with a different name.

## ERROR 5330 (HY000) : Synonym %s translation is no longer valid

* seekdb error code: 5330

* Cause: The object corresponding to the synonym does not exist.

* Solution: Create the object that the synonym depends on.

## ERROR 5331 (HY000) : name is already used by an existing object

* seekdb error code: 5331

* Cause: An object with the specified name already exists.

* Solution: You cannot create a new object with the same name as an existing object.

## ERROR 5337 (HY000) : rowid is wrong

* seekdb error code: 5337

* Cause: The content parsed from the `ROWID` column does not meet expectations.

* Solution: Pass a valid `ROWID`.

## ERROR 5338 (HY000) : Window Function not allowed here

* seekdb error code: 5338

* Cause: A window function appears in an expression in the SQL statement.

* Solution: Remove the window function from the corresponding expression in the SQL statement.

## ERROR 5339 (HY000) : Fail to parse list partition

* seekdb error code: 5339

* Cause: The number of partitions defined in the LIST partitioning clause does not match the number of partitioning clauses.

* Solution: Modify the number of partitions defined.

## ERROR 5341 (HY000) : timezone region ID is invalid

* seekdb error code: 5341

* Cause: The `Region ID` recorded in the `TIMESTAMP` data cannot be parsed.

* Solution: Contact technical support for assistance.

## ERROR 5342 (HY000) : invalid hex number

* seekdb error code: 5342

* Cause: The hexadecimal number is invalid.

* Solution: Contact technical support for assistance.

## ERROR 5343 (42000) : wrong number or types of arguments in call to '%.\*s'

* seekdb error code: 5343

* Cause: The number or types of arguments in the parameter list is incorrect.

* Solution: Check the parameter list.

## ERROR 5345 (HY000) : insufficient parallel query worker available

* seekdb error code: 5345

* Cause: The number of PX threads is insufficient.

* Solution: Increase the number of PX threads.

## ERROR 5346 (HY000) : FOR UPDATE of this query expression is not allowed

* seekdb error code: 5346

* Cause: The `FOR UPDATE` clause specifies an invalid expression.

* Solution: Modify the `FOR UPDATE` syntax.

## ERROR 5347 (HY000) : argument should be a function of expressions in PARTITION BY

* seekdb error code: 5347

* Cause: A parsing error occurs.

* Solution: Modify the SQL statement.

## ERROR 5348 (HY000) : result of string concatenation is too long

* seekdb error code: 5348

* Cause: The `WM_CONCAT` function is used to concatenate strings, and the concatenated string is too long.

* Solution: Check whether the length of the concatenated string exceeds the value of `group_concat_max_len`. If it does, increase the value of `group_concat_max_len`.

## ERROR 5350 (HY000) : updating partition key column would cause a partition change

* seekdb error code: 5350

* Cause: The `UPDATE` operation changes the partition to which the row belongs.

* Solution: Use the `ALTER TABLE` statement to enable the `ENABLE ROW MOVEMENT` attribute for the table.

## ERROR 5351 (HY000) : invalid type given for an argument

* seekdb error code: 5351

* Cause: The type of the argument is invalid.

* Solution: Check the type of the argument.

## ERROR 5352 (HY000) : specified field not found in datetime or interval

* seekdb error code: 5352

* Error cause: An error is found during timezone conversion.

* Solution: Contact technical support for troubleshooting.

## ERROR 5360 (HY000) : insufficient privileges

* seekdb error code: 5360

* Error cause: Insufficient privileges.

* Solution: Grant the corresponding privileges.

## ERROR 5361 (HY000) : user %.\*s lacks CREATE SESSION privilege; logon denied

* seekdb error code: 5361

* Error cause: The user does not have login privileges.

* Solution: Grant login privileges to the user.

## ERROR 5363 (HY000) : system privileges not granted to '%.\*s'

* seekdb error code: 5363

* Error cause: The user does not have system privileges.

* Solution: Grant the corresponding system privileges to the user.

## ERROR 5364 (HY000) : only SELECT and ALTER privileges are valid for sequences

* seekdb error code: 5364

* Error cause: Privileges other than `SELECT` and `ALTER` are granted to the SEQUENCE object.

* Solution: Do not grant privileges other than `SELECT` and `ALTER` to the SEQUENCE object.

## ERROR 5365 (HY000) : EXECUTE privilege not allowed for tables

* seekdb error code: 5365

* Error cause: The `EXECUTE` privilege is granted to the table.

* Solution: Do not grant the `EXECUTE` privilege to the table.

## ERROR 5366 (HY000) : only EXECUTE and DEBUG privileges are valid for procedures

* seekdb error code: 5366

* Error cause: Privileges other than `EXECUTE` and `DEBUG` are granted to the PROCEDURE object.

* Solution: Do not grant privileges other than `EXECUTE` and `DEBUG` to the PROCEDURE object.

## ERROR 5367 (HY000) : only EXECUTE, DEBUG, and UNDER privileges are valid for types

* seekdb error code: 5367

* Error cause: Privileges other than `EXECUTE`, `DEBUG`, and `UNDER` are granted to the TYPE object.

* Solution: Do not grant privileges other than `EXECUTE`, `DEBUG`, and `UNDER` to the TYPE object.

## ERROR 5368 (HY000) : ADMIN option not granted for role '%.\*s'

* seekdb error code: 5368

* Error cause: The role does not have the corresponding ADMIN option.

* Solution: Grant the ADMIN option to the role of the user.

## ERROR 5369 (HY000) : user or role '%.\*s' does not exist

* seekdb error code: 5369

* Error cause: The user does not exist.

* Solution: Check whether the username is written incorrectly. If it is incorrect, change it to the correct username. If it is correct, create the required username.

## ERROR 5370 (HY000) : missing ON keyword

* seekdb error code: 5370

* Error cause: The `ON` keyword is missing.

* Solution: Add the `ON` keyword.

## ERROR 5371 (HY000) : grant option does not exist for '%.\*s.%.\*s'

* seekdb error code: 5371

* Error cause: The user does not have the corresponding grant option.

* Solution: Grant the corresponding grant option.

## ERROR 5372 (HY000) : ALTER, INDEX and EXECUTE not allowed for views

* seekdb error code: 5372

* Error cause: The `ALTER`, `INDEX`, and `EXECUTE` privileges are granted to the VIEW object.

* Solution: Do not grant the `ALTER`, `INDEX`, or `EXECUTE` privilege to the VIEW object.

## ERROR 5373 (HY000) : circular role grant detected

* seekdb error code: 5373

* Error cause: A circular role grant is detected.

* Solution: Do not perform circular role grants.

## ERROR 5374 (HY000) : invalid privilege on directories

* seekdb error code: 5374

* Error cause: Incorrect privileges are granted to the directory object.

* Solution: Grant the correct privileges for operating the directory object.

## ERROR 5375 (HY000) : directory access denied

* seekdb error code: 5375

* Error cause: The user does not have the privilege for operating the directory.

* Solution: If you need to access the directory, contact the system administrator to grant the user the privilege for operating the directory.

## ERROR 5376 (HY000) : missing or invalid role name

* seekdb error code: 5376

* Error cause: The role name is incorrect.

* Solution: Correct the role name.

## ERROR 5377 (HY000) : role '%.\*s' not granted or does not exist

* seekdb error code: 5377

* Error cause: The role is not granted or does not exist.

## ERROR 5378 (HY000) : DEFAULT ROLE '%.\*s' not granted to user

* seekdb error code: 5378

* Error cause: The default role is not granted to the user.

* Solution: Grant the default role to the user.

## ERROR 5379 (HY000) : ROLE '%.\*s' not granted to '%.\*s'

* seekdb error code: 5379

* Error cause: The role is not granted to the user when the role is revoked from the user.

## ERROR 5380 (HY000) : cannot GRANT to a role WITH GRANT OPTION

* seekdb error code: 5380

* Error cause: The user does not have the grant option when the user grants the role.

* Solution: Grant the grant option to the user.

## ERROR 5381 (HY000) : duplicate username in list

* seekdb error code: 5381

* Error cause: The `GRANT` statement contains duplicate users.

* Solution: Remove the redundant users.

## ERROR 5382 (HY000) : cannot grant %.\*s to a role

* seekdb error code: 5382

* Error cause: The `REFERENCE` or `INDEX` privilege cannot be granted to the role.

* Solution: Remove the `REFERENCE` or `INDEX` privilege granted to the role.

## ERROR 5383 (HY000) : CASCADE CONSTRAINTS must be specified to perform this revoke

* seekdb error code: 5383

* Error cause: The `CASCADE CONSTRAINTS` option is not specified in the `REVOKE` statement.

* Solution: Specify the `CASCADE CONSTRAINTS` option.

## ERROR 5384 (HY000) : you may not GRANT/REVOKE privileges to/from yourself

* seekdb error code: 5384

* Error reason: Privileges are granted or revoked from the user.

* Solution: seekdb does not support granting or revoking privileges from the user. If you need to modify your privileges, contact the system administrator.

## ERROR 5386 (HY000) : Unable to read data -* Table definition has changed

* seekdb error code: 5386
* Compatible MySQL error code: 1412
* Error reason: The table definition has changed, and the snapshot point is too old to read or parse correctly.
* Solution: Check if the table definition has changed, and confirm whether columns have been added or deleted, or if data types or lengths have been modified.

## ERROR 5401 (HY000) : resultant data type of virtual column is not supported

* seekdb error code: 5401

* Error reason: Generated columns cannot reference large object types.

* Solution: Remove the large object type.

## ERROR 5403 (HY000) : ddl schema version not match

* seekdb error code: 5403

* Error reason: Concurrent DDL conflicts.

* Solution: Re-execute the DDL.

## ERROR 5409 (HY000) : Duplicate object name exists, schema refreshing may be hung

* seekdb error code: 5409
* Error reason: A duplicate object name exists during DDL thread execution.

* Solution: Contact technical support for assistance.

## ERROR 5410 (HY000) : Refresh schema failed continuously, ddl may be hung

* seekdb error code: 5410
* Error reason: The DDL thread is hung and cannot receive new DDL requests.
* Solution: Contact technical support for assistance.

## ERROR 5435 (HY000) : outline not reproducible

* seekdb error code: 5435

* Error reason: The outline plan cannot be reproduced.

* Solution: Contact technical support for assistance.

## ERROR 5436 (42000) : TIMESTAMP_TO_SCN expected timestamp argument

* seekdb error code: 5436

* Error reason: The parameter type does not match the expected type. The parameter passed to the TIMESTAMP_TO_SCN function must be of the Timestamp type.

* Solution: Modify the function parameters.

## ERROR 5437 (42000) : SCN_TO_TIMESTAMP expected a integer number as nsec argument

* seekdb error code: 5437

* Error reason: The parameter type does not match the expected type. The parameter passed to the SCN_TO_TIMESTAMP function must be an integer.

* Solution: Modify the function parameters.

## ERROR 5500 (HY000) : Legitimacy check failed for generated columns.

* seekdb error code: 5500
* Error reason: During the legitimacy check of generated columns or function indexes, the stored value is different from the value recalculated based on the current environment and the definition of the generated column or index. This may be due to the use of system variables or built-in functions with uncertain behavior to define the generated column or index. If the `_enable_defensive_check` configuration item is enabled, a defensive error will be reported.
* Solution: Check the definitions of the generated columns and function indexes. If the change in the calculation result is caused by a change in the system variable, delete and recreate the generated column or index. If the issue persists, contact technical support for assistance.

## ERROR 5540 (HY000) : System variable '%.*s' is different from the old value solidified for '%.*s'(old value:%.*s).

* seekdb error code: 5540

* Error reason: The system variable value set in the current session is different from the value fixed when the function index or generated column was created. During calculations, the function index or generated column will use the value fixed at the time of creation, not the current session variable value.

* Solution: If you need to calculate based on the current session's system variable value, delete and recreate the generated column or function index.

## ERROR 5558 (42000) : %s \\'%.\*s.%.\*s\\' already exists

* seekdb error code: 5558

* Error reason: The package to be created already exists.

* Solution: Use the `CREATE [OR REPLACE]` statement to create it. After execution, any existing package with the same name will be overwritten.

## ERROR 5559 (42000) : %s \\'%.\*s.%.\*s\\' does not exist

* seekdb error code: 5559

* Error reason: The accessed package does not exist.

* Solution: Check the logic.

## ERROR 5561 (HY000) : Invalid use of window function

* seekdb error code: 5561

* Error reason: The window function is used incorrectly, such as with unreasonable parameter settings.

* Solution: Modify the window to use the correct window function.

## ERROR 5562 (HY000) : Duplicate constraint name '%.\*s'

* seekdb error code: 5562

* Error reason: The constraint name already exists.

* Solution: Change the constraint name.

## ERROR 5563 (HY000) : Constraint not found

* seekdb error code: 5563

* Error reason: The constraint to be operated on does not exist.

* Solution: Check if the constraint name is correct.

## ERROR 5564 (HY000) : Duplicate alter index operations on column \\'%.\*s\\'

* seekdb error code: 5564

* Error reason: The same column is repeatedly operated on with `ALTER INDEX` in the same SQL statement.

* Solution: Modify the SQL statement.

## ERROR 5572 (HY000) : a partition may be split into exactly two new partitions

* seekdb error code: 5572

* Error reason: The `SPLIT` partition is not specified as 2.

* Solution: Specify the partition to be split into 2.

## ERROR 5573 (HY000) : this physical attribute may not be specified for a table partition

* seekdb error code: 5573

* Error reason: The maximum value is not supported as a split point during partition splitting.

* Solution: Fix the split point.

## ERROR 5574 (HY000) : missing VALUES keyword

* seekdb error code: 5574

* Error reason: Syntax error.

* Solution: Add the `VALUES` keyword.

## ERROR 5575 (HY000) : missing AT or VALUES keyword

* seekdb error code: 5575

* Error reason: Syntax error.

* Solution: Add the `AT` or `VALUES` keyword.

## ERROR 5578 (HY000) : Plan cache lock conflict

* seekdb error code: 5578

* Error reason: The plan cache lock failed.

* Solution: Retry.

## ERROR 5597 (HY000) : last resulting partition cannot contain bounds

* seekdb error code: 5597

* Error reason: The partition range is inconsistent before and after splitting.

* Solution: Modify the SQL statement.

## ERROR 5598 (HY000) : cannot add partition when DEFAULT partition exists

* seekdb error code: 5598

* Error reason: The LIST partition already has a default partition, and you cannot add more partitions.

* Solution: Do not add new partitions. Instead, use the partition splitting method to add partitions.

## ERROR 5599 (HY000) : cannot split partition into one partition, use rename instead

* seekdb error code: 5599

* Error reason: You cannot split a partition into one partition.

## ERROR 5601 (HY000) : Percentage should between 1 and 99

* seekdb error code: 5601

* Error reason: The parameter is invalid.

* Solution: Modify the SQL statement.

## ERROR 5603 (0A000) : Attempt to create, alter or drop an index on temporary table already in use

* seekdb error code: 5603

* Error reason: You are trying to create, modify, or drop an index on a temporary table that is in use.

* Solution: Disconnect all sessions that are using the temporary table, and then perform the operation.

## ERROR 5604 (HY000) : invalid NLS parameter string used in SQL function

* seekdb error code: 5604

* Error reason: The time parameter is invalid.

* Solution: Contact technical support.

## ERROR 5605 (HY000) : datetime/interval precision is out of range

* seekdb error code: 5605

* Error reason: The precision of the time parameter is out of range.

* Solution: Contact technical support.

## ERROR 5606 (42000) : Invalid number format model

* seekdb error code: 5606

* Error reason: The number format is invalid.

* Solution: Contact technical support.

## ERROR 5607 (HY000) : SQL command not properly ended

* seekdb error code: 5607

* Error reason: The command is not properly ended.

* Solution: Check the validity of the command.

## ERROR 5608 (42000) : invalid number format model

* seekdb error code: 5608

* Error reason: The number format is invalid.

* Solution: Contact technical support.

## ERROR 5613 (HY000) : too many values

* seekdb error code: 5613

* Error reason: The number of values specified in the statement is too large. This error commonly occurs in `INSERT` statements.

* Solution: Adjust the number of values or contact technical support.

## ERROR 5614 (HY000) : not enough values

* seekdb error code: 5614

* Error reason: The number of values specified in the statement is too small. This error commonly occurs in `INSERT` statements.

* Solution: Adjust the number of values or contact technical support.

## ERROR 5615 (HY000) : single-row subquery returns more than one row

* seekdb error code: 5615

* Error reason: The scalar subquery expression returns multiple rows instead of one row.

* Solution: Check the scalar subquery expression and ensure that it returns only one row of result set each time it is executed.

## ERROR 5616 (HY000) : UPDATE ... SET expression must be a subquery

* seekdb error code: 5616

* Error reason: In rowset assignment scenarios, the `SET` clause of the `UPDATE` statement must be specified as a `subquery`.

* Solution: Adjust the syntax of the `SET` clause in the `UPDATE` statement or contact technical support.

## ERROR 5617 (HY000) : inappropriate INTO

* seekdb error code: 5617

* Error reason: The `INTO` clause is used incorrectly.

* Solution: Contact technical support.

## ERROR 5619 (HY000) : Column part of using clause can not have qualifier

* seekdb error code: 5619

* Error reason: The column name in the `USING` clause cannot contain the `database name` or `table name`.

* Solution: Remove the `database name` or `table name` from the column name in the `USING` clause.

## ERROR 5623 (HY000) : outer join operator (+) not allowed in operand of OR or IN

* seekdb error code: 5623

* Error reason: The `OR` clause contains an outer join.

* Solution: Modify the SQL statement.

## ERROR 5624 (HY000) : a column may not be outer-joined to a subquery

* seekdb error code: 5624

* Error reason: The column in the `+` outer join cannot be outer-joined to a subquery.

* Solution: Modify the SQL statement.

## ERROR 5625 (HY000) : old style outer join (+) cannot be used with ANSI joins

* seekdb error code: 5625

* Error reason: When the query block uses ANSI-style joins, you cannot use the old-style notation for specifying outer joins (+).

* Solution: Modify the SQL statement.

## ERROR 5626 (HY000) : outer join operator (+) is not allowed here

* seekdb error code: 5626

* Error reason: You are trying to reference the (+) operator in the `select_list`, `CONNECT BY`, `START WITH`, or `ORDER BY` clause.

* Solution: Modify the SQL statement.

## ERROR 5627 (HY000) : Schema try again

* seekdb error code: 5627

* Error reason: The local schema version is outdated.

* Solution: Retry the operation or contact technical support.

## ERROR 5628 (HY000) : zero-length columns are not allowed

* seekdb error code: 5628

* Error reason: The column data length is 0.

* Solution: Contact technical support.

## ERROR 5629 (HY000) : year conflicts with Julian date

* seekdb error code: 5629

* Error reason: The year and Julian date conflict. For example, `SELECT TO_DATE('2021-03-23 2459063', 'YYYY MM DD J') FROM DUAL;`.

## ERROR 5630 (HY000) : day of year conflicts with Julian date

* seekdb error code: 5630

* Error reason: The day of the year (1-366) and the Julian date conflict.

## ERROR 5631 (HY000) : month conflicts with Julian date

* seekdb error code: 5631

* Error cause: The month and Julian date are conflicting. For example, `SELECT TO_DATE('11 2459063','MM J') FROM DUAL;`.

## ERROR 5632 (HY000) : day of month conflicts with Julian date

* seekdb error code: 5632

* Error cause: The day of the month (1 - 31) and Julian date are conflicting. For example, `SELECT TO_DATE('11 2459063','DD J') FROM DUAL;`.

## ERROR 5633 (HY000) : day of week conflicts with Julian date

* seekdb error code: 5633

* Error cause: The day of the week (1 - 7) and Julian date are conflicting. For example, `SELECT TO_DATE('3 2459063','D J') FROM DUAL;`.

## ERROR 5634 (HY000) : hour conflicts with seconds in day

* seekdb error code: 5634

* Error cause: The hour and seconds in a day are conflicting.

## ERROR 5635 (HY000) : minutes of hour conflicts with seconds in day

* seekdb error code: 5635

* Error cause: The minutes in an hour and seconds in a day are conflicting.

## ERROR 5636 (HY000) : seconds of minute conflicts with seconds in day

* seekdb error code: 5636

* Error cause: The seconds in a minute and seconds in a day are conflicting.

## ERROR 5637 (HY000) : date not valid for month specified

* seekdb error code: 5637

* Error cause: The date is invalid for the specified month.

## ERROR 5638 (HY000) : input value not long enough for date format

* seekdb error code: 5638

* Error cause: The input value is not long enough for the date format.

## ERROR 5639 (HY000) : (full) year must be between -4713 and +9999, and not be 0

* seekdb error code: 5639

* Error cause: The year of a valid date must be between 1 and 9999.

## ERROR 5640 (HY000) : quarter must be between 1 and 4

* seekdb error code: 5640

* Error cause: The value of the quarter must be between 1 and 4.

## ERROR 5641 (HY000) : not a valid month

* seekdb error code: 5641

* Error cause: The value is not a valid month.

## ERROR 5642 (HY000) : not a valid day of the week

* seekdb error code: 5642

* Error cause: The value is not a valid day of the week.

## ERROR 5643 (HY000) : day of year must be between 1 and 365 (366 for leap year)

* seekdb error code: 5643

* Error cause: The value of the day of the year must be between 1 and 365 (366 for a leap year).

## ERROR 5644 (HY000) : hour must be between 1 and 12

* seekdb error code: 5644

* Error cause: The hour must be between 1 and 12.

## ERROR 5645 (HY000) : hour must be between 0 and 23

* seekdb error code: 5645

* Error cause: The hour must be between 0 and 23.

## ERROR 5646 (HY000) : minutes must be between 0 and 59

* seekdb error code: 5646

* Error cause: The minutes must be between 0 and 59.

## ERROR 5647 (HY000) : seconds must be between 0 and 59

* seekdb error code: 5647

* Error cause: The seconds must be between 0 and 59.

## ERROR 5648 (HY000) : seconds in day must be between 0 and 86399

* seekdb error code: 5648

* Error cause: The seconds in a day must be between 0 and 86399.

## ERROR 5649 (HY000) : julian date must be between 1 and 5373484

* seekdb error code: 5649

* Error cause: The input Julian date is invalid.

* Solution: The input Julian date must be between 1 and 5373484.

## ERROR 5650 (HY000) : AM/A.M. or PM/P.M. required

* seekdb error code: 5650

* Error cause: The `AM`, `A.M.`, `PM`, or `P.M.` date format must be specified.

## ERROR 5651 (HY000) : BC/B.C. or AD/A.D. required

* seekdb error code: 5651

* Error cause: The `BC`, `B.C.`, `AD`, or `A.D.` date format must be specified.

## ERROR 5652 (HY000) : format code appears twice

* seekdb error code: 5652

* Error cause: The format model is invalid.

* Solution: Contact technical support for assistance.

## ERROR 5653 (HY000) : day of week may only be specified once

* seekdb error code: 5653

* Error cause: The day of the week can be specified only once.

## ERROR 5654 (HY000) : signed year precludes use of BC/AD

* seekdb error code: 5654

* Error cause: A signed date cannot contain both `BC` or `AD`.

## ERROR 5655 (HY000) : Julian date precludes use of day of year

* seekdb error code: 5655

* Error cause: The Julian date and day of the year cannot be used together.

## ERROR 5656 (HY000) : year may only be specified once

* seekdb error code: 5656

* Error cause: The year can be specified only once.

## ERROR 5657 (HY000) : hour may only be specified once

* seekdb error code: 5657

* Error cause: The hour can be specified only once.

## ERROR 5658 (HY000) : AM/PM conflicts with use of A.M./P.M

* seekdb error code: 5658

* Error cause: `AM` or `PM` conflicts with the corresponding `A.M.` or `P.M.`.

## ERROR 5659 (HY000) : BC/AD conflicts with use of B.C./A.D

* seekdb error code: 5659

* Error cause: `BC` or `AD` conflicts with the corresponding `B.C.` or `A.D.`.

## ERROR 5660 (HY000) : month may only be specified once

* seekdb error code: 5660

* Error cause: The month can be specified only once.

## ERROR 5661 (HY000) : day of week may only be specified once

* seekdb error code: 5661

* Error reason: The day of the week can be specified only once.

## ERROR 5662 (HY000) : format code cannot appear in date input format

* seekdb error code: 5662

* Error reason: The format model is invalid.

* Solution: Check whether the number format model meets the syntax requirements.

## ERROR 5663 (HY000) : a non-numeric character was found where a numeric was expected

* seekdb error code: 5663

* Error reason: An invalid numeric character is found.

* Solution: Check whether the SQL statement contains invalid numeric characters.

## ERROR 5664 (HY000) : 'HH24' precludes use of meridian indicator

* seekdb error code: 5664

* Error reason: The format model H24 appears with `AM` or `PM`.

* Solution: Contact technical support.

## ERROR 5665 (HY000) : missing or illegal character following the escape character

* seekdb error code: 5665

* Error reason: The character following the `ESCAPE` field in the `LIKE` query statement is invalid.

* Solution: Check whether the character following the `ESCAPE` field in the `LIKE` statement meets the requirements.

## ERROR 5666 (HY000) : escape character must be character string of length 1

* seekdb error code: 5666

* Error reason: The character following the `ESCAPE` field in the `LIKE` query statement is not a single character.

* Solution: Specify the character following the `ESCAPE` field as a single character.

## ERROR 5667 (HY000) : day of month must be between 1 and last day of month

* seekdb error code: 5667

* Error reason: The value of the day of the month must be between 1 and the last day of the month.

## ERROR 5668 (HY000) : not a SELECTed expression

* seekdb error code: 5668

* Error reason: The expression specified in the `GROUP BY` clause is not specified in the `SELECT` clause.

* Solution: Modify the syntax of the SQL statement.

## ERROR 5670 (HY000) : (full) year must be between -4713 and +9999, and not be 0

* seekdb error code: 5670

* Error reason: The year of a valid date must be between 1 and 9999.

## ERROR 5671 (HY000) : such unique or primary key already exists in the table

* seekdb error code: 5671

* Error reason: A unique index already exists.

* Solution: A unique index cannot be created again.

## ERROR 5672 (HY000) : such column list already indexed

* seekdb error code: 5672

* Error reason: An index is created again.

* Solution: An index cannot be created again.

## ERROR 5674 (HY000) : argument '%ld' is out of range

* seekdb error code: 5674

* Error reason: The specified parameter is out of range.

* Solution: Adjust the parameter value **.**

## ERROR 5675 (HY000) : ORDER BY item must be the number of a SELECT-list expression

* seekdb error code: 5675

* Error reason: The `ORDER BY` item is not the correct number of the `SELECT` item.

* Solution: Adjust the `ORDER BY` clause in the SQL statement.

## ERROR 5676 (HY000) : the interval is invalid

* seekdb error code: 5676

* Error reason: The parameter is invalid.

* Solution: Contact technical support.

## ERROR 5677 (HY000) : PL/SQL: numeric or value error: %.\*s

* seekdb error code: 5677

* Error reason: An invalid numeric or other type of data is encountered during the execution of PL.

* Solution: Check whether the logic is correct.

## ERROR 5678 (HY000) : name already used by an existing constraint

* seekdb error code: 5678

* Error reason: The constraint name already exists.

* Solution: Change the constraint name.

## ERROR 5679 (HY000) : table must have at least one column that is not invisible

* seekdb error code: 5679
* Compatible with MySQL error code: 4028
* Error reason: A function index adds a hidden column to the table. This error is returned when all visible columns are deleted from the table that contains a hidden column.
* Solution: Check the column definitions and metadata of the data table. Ensure that at least one column is a visible column after the deletion operation is completed.

## ERROR 5680 (HY000) : Invisible column is not supported on this type of table

* seekdb error code: 5680

* Error reason: The temporary table does not support defining a column as `INVISIBLE`.

## ERROR 5681 (HY000) : Column visibility modifications cannot be combined with any other modified column DDL option

* seekdb error code: 5681

* Error reason: The DDL statement does not support adjusting column visibility and other column attributes at the same time.

* Solution: Split the DDL statement to adjust column visibility separately.

## ERROR 5683 (HY000) : too many arguments for function

* seekdb error code: 5683

* Error reason: The function has too many parameters.

* Solution: Adjust the number of parameters.

## ERROR 5684 (HY000) : PX sql need retry

* seekdb error code: 5684

* Error reason: Internal error code. Notify PX to retry the SQL statement.

* Solution: This error usually does not occur. If you encounter this error, check whether the system switchover and network status are normal.

## ERROR 5686 (HY000) : invalid extract field for extract source

* seekdb error code: 5686

* Error reason: The `EXTRACT` function cannot resolve the specified value domain.

* Solution: Check whether the specified value domain is valid.

## ERROR 5687 (42000) : %s \\'%.\*s.%.\*s\\' compile error

* seekdb error code: 5687

* Error reason: The compilation of the PACKAGE or UDT fails.

* Solution: Modify the error based on the error message.

## ERROR 5690 (HY000) : subquery not allowed here

* seekdb error code: 5690

* Error reason: A subquery is not allowed in this location.

* Solution: Contact technical support.

## ERROR 5691 (HY000) : date or system variable wrongly specified in CHECK constraint

* seekdb error code: 5691

* Error reason: The `DATE` function or system variable is not allowed in the `CHECK` constraint.

## ERROR 5692 (HY000) : Cannot drop constraint - nonexistent constraint

* seekdb error code: 5692

* Error reason: The constraint does not exist.

## ERROR 5693 (HY000) : check constraint violated

* seekdb error code: 5693

* Error reason: The `CHECK` constraint is not satisfied.

* Solution: Check whether the data in the columns involved in the DML operation meets the existing `CHECK` constraint.

## ERROR 5694 (HY000) : group function is not allowed here

* seekdb error code: 5694

* Error reason: The aggregate function is specified in an illegal position.

* Solution: Adjust the aggregate function in the SQL statement.

## ERROR 5695 (HY000) : policy string not found

* seekdb error code: 5695

* Error reason: The security policy is not found.

* Solution: Create a security policy.

## ERROR 5696 (HY000) : invalid label string

* seekdb error code: 5696

* Error reason: The label string is invalid.

* Solution: Specify a valid label string.

## ERROR 5697 (HY000) : undefined compartment string for policy string

* seekdb error code: 5697

* Error reason: The Compartment string is invalid.

* Solution: Specify a valid Compartment string.

## ERROR 5698 (HY000) : undefined level string for policy string

* seekdb error code: 5698

* Error reason: The Level string is invalid.

* Solution: Specify a valid Level string.

## ERROR 5699 (HY000) : undefined group string for policy string

* seekdb error code: 5699

* Error reason: The Group string is invalid.

* Solution: Specify a valid Group string.

## ERROR 5700 (HY000) : LBAC error: %s

* seekdb error code: 5700

* Error reason: The general label security error. For more information, see the specific error message.

* Solution: Modify the corresponding operation based on the error message.

## ERROR 5701 (HY000) : policy role already exists for policy string

* seekdb error code: 5701

* Error reason: The policy name already exists.

* Solution: Check and correct the policy name, or delete the existing policy.

## ERROR 5702 (HY000) : NULL or invalid user label: %s

* seekdb error code: 5702

* Error reason: The user label is invalid.

* Solution: Specify a valid user label.

## ERROR 5703 (HY000) : Add index failed

* seekdb error code: 5703

* Error reason: The index addition failed.

* Solution: Check whether the index is valid. If not, delete the index and create it again.

## ERROR 5704 (HY000) : profile %.\*s does not exist

* seekdb error code: 5704

* Error reason: The profile name is invalid.

* Solution: Check the profile name.

## ERROR 5705 (HY000) : invalid resource limit %s

* seekdb error code: 5705

* Error reason: The `FAILED_LOGIN_ATTEMPTS` or `PASSWORD_LOCK_TIME` parameter specified in the Profile-related DDL statement is not a valid integer, or the value is `0`.

* Solution: Adjust the parameter value in the Profile-related DDL statement.

## ERROR 5706 (HY000) : profile %.\*s already exists

* seekdb error code: 5706

* Error reason: The profile already exists.

* Solution: Change the profile name **.**

## ERROR 5707 (HY000) : profile %.\*s has users assigned, cannot drop without CASCADE

* seekdb error code: 5707

* Error reason: The profile has users assigned. You can only drop it by using the `CASCADE` option.

* Solution: Add the `CASCADE` option.

## ERROR 5708 (HY000) : the leading precision of the interval is too small

* seekdb error code: 5708

* Error reason: The precision is invalid.

* Solution: Contact technical support.

## ERROR 5709 (HY000) : time zone hour must be between -12 and 14

* seekdb error code: 5709

* Error reason: The hour specified for the `time_zone` system variable is out of the valid range.

* Solution: In MySQL mode, the valid range is \[-12, 14\].

## ERROR 5710 (HY000) : time zone minute must be between -59 and 59

* seekdb error code: 5710

* Error reason: The minute specified for the `time_zone` system variable is out of the valid range.

* Solution: The valid range is \[-59, 59\].

## ERROR 5711 (HY000) : not a valid time zone

* seekdb error code: 5711

* Error reason: The `TZD`, `TZH`, `TZM`, and `TZR` parameters cannot be specified in the `DATE` format.

## ERROR 5712 (HY000) : date format is too long for internal buffer

* seekdb error code: 5712

* Error reason: The `DATE` format is too long.

* Solution: Reduce the length of the `DATE` format.

## ERROR 5713 (HY000) : cannot validate (%.\*s.%.\*s) - check constraint violated

* seekdb error code: 5713

* Error reason: The input data violates the constraint.

* Solution: Contact technical support.

## ERROR 5714 (HY000) : data manipulation operation not legal on this view

* seekdb error code: 5714

* Error reason: You tried to modify a view that cannot be updated, such as a view with generated columns, expression columns, or data from multiple tables, by using the `INSERT`, `UPDATE`, or `DELETE` statement.

* Solution: Directly modify the base table or redefine the view.

## ERROR 5715 (HY000) : virtual column not allowed here

* seekdb error code: 5715

* Error reason: You tried to modify an expression column in a view by using the `INSERT`, `DELETE`, or `UPDATE` statement.

* Solution: Directly modify the base table.

## ERROR 5716 (HY000) : cannot modify more than one base table through a join view

* seekdb error code: 5716

* Error cause: The column belongs to multiple tables and cannot be inserted or updated.

* Solution: Split the statement into multiple statements.

## ERROR 5721 (HY000) : cannot delete from view without exactly one key-preserved table

* seekdb error code: 5721

* Error cause: The table to be deleted does not have a key-preserved table, or there are multiple key-preserved tables, or the key-preserved table comes from a read-only view.

* Solution: Redefine the view or perform the delete operation on the base table.

## ERROR 5722 (HY000) : cannot modify a column which maps to a non key-preserved table

* seekdb error code: 5722

* Error cause: Attempting to insert or update a non-key-preserved table in a JOIN view.

* Solution: Directly modify the base table.

## ERROR 5723 (HY000) : cannot perform a DML operation on a read-only view

* seekdb error code: 5723

* Error cause: Attempting to modify a view defined as read-only using `INSERT`, `DELETE`, or `UPDATE` statements.

* Solution: Directly modify the base table or redefine the view as an updatable view.

## ERROR 5724 (HY000) : invalid INITRANS option value

* seekdb error code: 5724

* Error cause: The value of the `INITRANS` parameter is invalid.

* Solution: Adjust the parameter value.

## ERROR 5725 (HY000) : invalid MAXTRANS option value

* seekdb error code: 5725

* Error cause: The value of the `MAXTRANS` parameter is invalid.

* Solution: Adjust the parameter value.

## ERROR 5726 (HY000) : invalid value for PCTFREE or PCTUSED

* seekdb error code: 5726

* Error cause: The value of the `PCTFREE` or `PCTUSED` parameter is invalid.

* Solution: Adjust the parameter value.

## ERROR 5728 (HY000) : illegal argument for function

* seekdb error code: 5728

* Error cause: The parameter is invalid.

* Solution: Adjust the parameter value.

## ERROR 5729 (HY000) : this operator cannot be used with lists

* seekdb error code: 5729

* Error cause: Vector comparison operations are not supported.

* Solution: Remove the vector comparison operation.

## ERROR 5730 (HY000) : SAMPLE percentage must be in the range \[0.000001,100)

* seekdb error code: 5730

* Error cause: Parsing error.

* Solution: Modify the SQL statement.

## ERROR 5731 (HY000) : specifying owner's name of the table is not allowed

* seekdb error code: 5731

* Error cause: When renaming a table object, the username cannot be specified.

## ERROR 5732 (HY000) : stmt trigger with when clause

* seekdb error code: 5732

* Error cause: Statement-level triggers cannot specify `WHEN` conditions.

* Solution: Remove the `WHEN` condition from the statement-level trigger.

## ERROR 5732 (HY000) : not enough arguments for function

* seekdb error code: 5732

* Error cause: The number of function parameters is insufficient.

* Solution: Add the missing parameters.

## ERROR 5733 (HY000) : trigger '%.\*s' does not exist

* seekdb error code: 5733

* Error cause: The specified trigger does not exist.

* Solution: Confirm whether the specified trigger exists.

## ERROR 5734 (HY000) : trigger '%.\*s' already exist

* seekdb error code: 5734

* Error cause: The specified trigger already exists.

* Solution: Confirm whether the specified trigger exists.

## ERROR 5735 (HY000) : trigger '%.\*s' already exists on another table, cannot replace it

* seekdb error code: 5735

* Error cause: Another table already has a trigger with the same name, so the current trigger cannot be created.

* Solution: Rename the current trigger and then create it.

## ERROR 5736 (HY000) : error signaled in parallel query server

* seekdb error code: 5736

* Error cause: Internal error code. When PX needs to terminate execution, it broadcasts this error code to all execution nodes to terminate the current execution.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 5763 (HY000) : Specified pseudo column or operator not allowed here

* seekdb error code: 5763

* Error cause: The `LEVEL`, `PRIOR`, `ROWNUM`, `CONNECT_BY_ROOT`, `CONNECT_BY_ISLEAF`, or `CONNECT_BY_ISCYCLE` keyword cannot be used in this location.

* Solution: Remove the `LEVEL`, `PRIOR`, `ROWNUM`, `CONNECT_BY_ROOT`, `CONNECT_BY_ISLEAF`, or `CONNECT_BY_ISCYCLE` keyword.

## ERROR 5764 (HY000) : CONNECT BY loop in user data

* seekdb error code: 5764

* Error cause: A `CONNECT BY` loop exists in the user data.

## ERROR 5765 (HY000) : cannot have join with CONNECT BY

* seekdb error code: 5765

* Error cause: Cannot join with `CONNECT BY`.

## ERROR 5766 (HY000) : CONNECT BY clause required in this query block

* seekdb error code: 5766

* Error cause: The `CONNECT BY` clause is required in this query block.

## ERROR 5768 (HY000) : SYS_CONNECT_BY_PATH function is not allowed here

* seekdb error code: 5768

* Error cause: The `SYS_CONNECT_BY_PATH` function is called outside the `SELECT` list and `ORDER BY` clause.

* Solution: Remove the call to the `SYS_CONNECT_BY_PATH` function outside the `SELECT` list and `ORDER BY` clause.

## ERROR 5769 (HY000) : illegal parameter in SYS_CONNECT_BY_PATH function

* seekdb error code: 5769

* Error cause: The `SYS_CONNECT_BY_PATH` function contains an illegal parameter.

## ERROR 5770 (HY000) : A column value contained the string that the SYS_CONNECT_BY_PATH function was to use to separate column values

* seekdb error code: 5770

* Cause: The column value contains the string that the `SYS_CONNECT_BY_PATH` function uses to separate column values.

* Solution: Specify a different delimiter for the `SYS_CONNECT_BY_PATH` function and ensure that the delimiter is not present in any column values.

## ERROR 5771 (HY000) : CONNECT BY ROOT operator is not supported in the START WITH or in the CONNECT BY condition

* seekdb error code: 5771

* Cause: The `CONNECT BY ROOT` operator is used in the `START WITH` or `CONNECT BY` condition.

* Solution: Remove the `CONNECT BY ROOT` operator from the `START WITH` or `CONNECT BY` condition.

## ERROR 5772 (HY000) : ORDER SIBLINGS BY clause not allowed here

* seekdb error code: 5772

* Cause: The `ORDER SIBLINGS BY` clause is specified in a query that does not contain the `CONNECT BY` clause.

* Solution: Remove the `ORDER SIBLINGS BY` clause or add the `CONNECT BY` clause to the query.

## ERROR 5773 (HY000) : NOCYCLE keyword is required with CONNECT_BY_ISCYCLE pseudo column

* seekdb error code: 5773

* Cause: The `CONNECT_BY_ISCYCLE` pseudo column is specified in a query that does not contain the `NOCYCLE` keyword.

* Solution: Remove the `CONNECT_BY_ISCYCLE` pseudo column or add the `NOCYCLE` keyword.

## ERROR 5774 (HY000) : not enough arguments for function

* seekdb error code: 5774

* Cause: The function has insufficient arguments.

## ERROR 5777 (HY000) : Prepare statement checksum error

* seekdb error code: 5777

* Cause: The server session is in an unrecoverable state.

* Solution: Log in to seekdb again to automatically create a new server session. For more information, see the session trace file.

## ERROR 5778 (HY000) : cannot enable constraint (%.\*s) - no such constraint

* seekdb error code: 5778

* Cause: The specified constraint does not exist in this table.

## ERROR 5779 (HY000) : cannot disable constraint (%.\*s) - no such constraint

* seekdb error code: 5779

* Cause: The specified constraint does not exist in this table.

## ERROR 5780 (HY000) : PX DOP downgrade from %ld to %ld

* seekdb error code: 5780

* Cause: Normal exit.

## ERROR 5781 (HY000) : parallel_max_servers downgrade due to insufficent cpu resource from %ld to %ld. deprecated

* seekdb error code: 5781

* Cause: Normal exit.

  <main id="notice" type='explain'>
    <h4>Note</h4>
    <p>This error code is no longer used. </p>
  </main>

## ERROR 5785 (HY000) : cannot validate (%.\*s.%.\*s) - parent keys not found

* seekdb error code: 5785

* Cause: The operation to change the table failed because the table has orphaned child records.

## ERROR 5786 (HY000) : Column check constraint cannot reference other columns

* seekdb error code: 5786

* Cause: A column check constraint that references another column is defined.

* Solution: Define a table check constraint instead.

## ERROR 5787 (HY000) : batched multi statement execution needs rollback

* seekdb error code: 5787

* Cause: The execution method for batched multi-statement queries is not supported.

* Solution: No action is required. seekdb automatically reverts to single-statement execution.

## ERROR 5788 (HY000) : cannot select FOR UPDATE from view with ISTINCT, GROUP BY, etc

* seekdb error code: 5788

* Cause: The `FOR UPDATE` clause is used in a query that selects from a view that has not been merged. The view is not merged because it uses syntax that prevents merging (such as `DISTINCT` or `GROUP BY`) or due to parameter settings in the initialization file.

* Solution: Determine why the view is not merged and modify the syntax to allow merging.

## ERROR 5789 (HY000) : policy with check option violation

* seekdb error code: 5789

* Cause: The security tag for the written data is incorrect.

## ERROR 5790 (HY000) : policy already applied to table

* seekdb error code: 5790

* Cause: The policy is applied to a table that is already protected by the policy.

* Solution: To change the policy options, predicate, or tag value, remove the policy from the table and reapply it.

## ERROR 5791 (HY000) : table '%.\*s'.'%.\*s' is mutating, trigger/function may not see it

* seekdb error code: 5791

* Cause: A trigger (or a user-defined `plsql` function referenced in this statement) attempts to view (or modify) a table while a statement that triggers the table is modifying the table.

* Solution: Rewrite the trigger (or function) so that it does not read the table.

## ERROR 5792 (HY000) : column is referenced in a multi-column constraint

* seekdb error code: 5792

* Cause: Attempting to drop a column that is referenced by a constraint.

* Solution: Drop all constraints that reference the column or specify `CASCADE CONSTRAINTS` in the statement.

## ERROR 5793 (HY000) : cannot drop parent key column

* seekdb error code: 5793

* Cause: Attempting to drop a parent key column that is referenced by a constraint.

* Solution: Drop all constraints that reference the parent key column or specify `CASCADE CONSTRAINTS` in the statement.

## ERROR 5794 (HY000) : auto increment service busy

* seekdb error code: 5794

* Cause: Internal error code.

* Solution: Contact technical support for assistance.

## ERROR 5795 (HY000) : No insert/update/delete on table with constraint (%.\*s.%.\*s) disabled and validated

* seekdb error code: 5795

* Error reason: An attempt is made to insert, update, or delete data in a table with a `DISABLE VALIDATE` constraint.

* Solution: Change the constraint status.

## ERROR 5796 (HY000) : active autonomous transaction detected and rolled back

* seekdb error code: 5796

* Error reason: All autonomous transactions started in the autonomous PL block must complete (committed or rolled back) before returning from the block. If not, the running autonomous transaction is implicitly rolled back, and this error code is returned.

* Solution: Ensure that any running autonomous transactions are explicitly committed or rolled back before returning from the autonomous PL block.

## ERROR 5797 (HY000) : ORDER BY not allowed here

* seekdb error code: 5797

* Error reason: The `ORDER BY` clause cannot be used with the `DISTINCT` function and the `RATIO_TO_REPORT` function.

## ERROR 5798 (HY000) : DISTINCT not allowed here

* seekdb error code: 5798

* Error reason: The `DISTINCT` option cannot be used with this function.

## ERROR 5799 (HY000) : assign user variable with := only allowed in select filed list and as root expression

* seekdb error code: 5799

* Error reason: The `:=` operator cannot be used to assign values to user variables unless it appears in the `SELECT` clause and is the root expression.

* Solution: Do not use the `:=` operator to assign values to user variables.

## ERROR 5800 (HY000) : cannot modify constraint (%.\*s) - no such constraint

* seekdb error code: 5800

* Error reason: The specified constraint does not exist in the table.

## ERROR 5801 (HY000) : implementation restriction: exception handler in nested transaction is illegal

* seekdb error code: 5801

* Error reason: An exception cannot be captured in a nested transaction.

* Solution: Remove the exception capture in the nested transaction.

## ERROR 5802 (HY000) : invalid ROWID

* seekdb error code: 5802

* Error reason: The `ROWID` is invalid.

## ERROR 5803 (HY000) : Invalid column in the INSERT VALUES Clause:'%.\*s'.'%.\*s'

* seekdb error code: 5803

* Error reason: The `INSERT VALUES` clause references an invalid table column.

## ERROR 5804 (HY000) : incorrect use of the \['%.\*s'\] operator

* seekdb error code: 5804

* Error reason: An error occurs during the execution of the operation.

* Solution: Check the parameters and return type of the operator.

## ERROR 5805 (HY000) : non-constant expression is not allowed for pivot\|unpivot values

* seekdb error code: 5805

* Error reason: A non-constant expression is used for `pivot|unpivot` values.

* Solution: Use a constant expression for `pivot|unpivot` values.

## ERROR 5806 (HY000) : expect aggregate function inside pivot operation

* seekdb error code: 5806

* Error reason: A non-aggregate function is used in the `pivot` operation.

* Solution: Use an aggregate function.

## ERROR 5807 (HY000) : expression must have same datatype as corresponding expression

* seekdb error code: 5807

* Error reason: The expression must have the same data type as the corresponding expression.

## ERROR 5808 (HY000) : character set mismatch

* seekdb error code: 5808

* Error reason: One of the following conditions may be true:

  * The string operands of the operator or built-in function (except for the `nlsparams` parameter) use different character sets.

  * The `nlsparams` operand is not in the database character set.

  * The string data passed to the built-in function uses a character set other than the database character set, but the built-in function does not support that character set.

  * The second parameter of `CHR（）` or `CSCONVERT（）` is not `CHAR_CS` or `NCHAR_CS`.

  * The character set of the string expression in the `VALUES` clause of the `INSERT` statement or the `SET` clause of the `UPDATE` statement does not match the character set of the column to which the data is being inserted.

  * The character set of the value provided in the `DEFAULT` clause when creating the table does not match the character set declared for the column.

  * The parameters of the `PL/SQL` function do not meet the character set requirements of the corresponding parameters.

## ERROR 5809 (HY000) : regular expression failed to match

* seekdb error code: 5809

* Error reason: The regular expression fails to match any string.

* Solution: This is an internal error. Contact technical support for assistance.

## ERROR 5810 (HY000) : invalid regular expression (reg version 0.8)

* seekdb error code: 5810

* Error reason: The given regular expression `pattern` is invalid.

* Solution: Adjust the given regular expression `pattern`.

## ERROR 5811 (HY000) : invalid escape \\\\ sequence in regular expression

* seekdb error code: 5811

* Error reason: An invalid `ESCAPE` is found in the regular expression.

* Solution: Remove the invalid `ESCAPE`.

## ERROR 5812 (HY000) : unmatched bracket in regular expression

* seekdb error code: 5812

* Error reason: The regular expression does not have matching brackets.

* Solution: Ensure that the brackets are matched.

## ERROR 5813 (HY000) : unmatched parentheses in regular expression

* seekdb error code: 5813

* Error reason: The regular expression does not have matching parentheses.

* Solution: Ensure that the parentheses are matched.

## ERROR 5814 (HY000) : invalid back reference in regular expression

* seekdb error code: 5814

* Error reason: A backward reference is found in a subexpression.

* Solution: Ensure that the subexpression is valid.

## ERROR 5815 (HY000) : invalid range in regular expression

* seekdb error code: 5815

* Error reason: An invalid range is found in the regular expression.

* Solution: Ensure that a valid range is used.

## ERROR 5816 (HY000) : invalid character class in regular expression

* seekdb error code: 5816

* Error reason: An unknown character class is found in the regular expression.

* Solution: Ensure that a valid character class is used.

## ERROR 5817 (HY000) : invalid collation class in regular expression

* seekdb error code: 5817

* Error reason: The regular expression contains an unknown collation class.

* Solution: Make sure that you use a valid collation class.

## ERROR 5818 (HY000) : braces {} not balanced in regular expression

* seekdb error code: 5818

* Error reason: The braces {} in the regular expression are not properly closed.

* Solution: Correct the braces {} in the regular expression.

## ERROR 5819 (HY000) : invalid repetition count(s) in regular expression

* seekdb error code: 5819

* Error reason: The regular expression engine encounters an invalid repetition count.

* Solution: Contact technical support for assistance.

## ERROR 5820 (HY000) : The regular expression was too complex and current library can't be parsed

* seekdb error code: 5820

* Error reason: The regular expression is too complex for the current regular expression engine to parse.

* Solution: Contact technical support for assistance.

## ERROR 5821 (HY000) : regular expression internal error

* seekdb error code: 5821

* Error reason: The regular expression is too complex for the current regular expression engine to parse.

* Solution: Contact technical support for assistance.

## ERROR 5822 (HY000) : invalid argument in regular expression

* seekdb error code: 5822

* Error reason: The regular expression contains an invalid argument.

* Solution: Check the validity of the arguments in the regular expression.

## ERROR 5823 (HY000) : character widths of regex and string differ in regular expression

* seekdb error code: 5823

* Error reason: The regular expression engine encounters a mix of character sets.

* Solution: Contact technical support for assistance.

## ERROR 5824 (HY000) : invalid embedded option in regular expression

* seekdb error code: 5824

* Error reason: The `pattern` parameter in the regular expression specifies an invalid matching parameter.

* Solution: Correct the `pattern` matching parameter in the regular expression.

## ERROR 5825 (HY000) : nfa has too many states in regular expression, may be the regular expression too long

* seekdb error code: 5825

* Error reason: The regular expression engine encounters an abnormal state transition.

* Solution: Contact technical support for assistance.

## ERROR 5827 (HY000) : the definition of relative objects have been modified, please check and retry

* seekdb error code: 5827

* Error reason: A conflict occurs during concurrent DDL operations.

* Solution: This is an internal error code. Contact technical support for assistance.

## ERROR 5828 (HY000) : Subscript beyond count

* seekdb error code: 5828

* Error reason: The subscript exceeds the maximum length of the VARRAY array or the subscript is too large for a nested table.

* Solution: Check the program logic and explicitly extend it if necessary.

## ERROR 5829 (HY000) : PARTITION () clause on non partitioned table

* seekdb error code: 5829

* Error reason: The table or index is not partitioned. The syntax is invalid.

* Solution: Retry the command by using the correct syntax.

## ERROR 5830 (HY000) : Unknown subpartition

* seekdb error code: 5830

* Error reason: The subpartition of the object is not found.

* Solution: Retry the command by using the correct subpartition name.

## ERROR 5831 (HY000) : Invalid SQL ROW LIMITING expression was specified

* seekdb error code: 5831

* Error reason: The SQL `ROW LIMITING` expression contains components other than text, bind variables, correlated variables, or subqueries.

* Solution: Modify the SQL `ROW LIMITING` expression and retry the operation.

## ERROR 5833 (HY000) : not implemented in SQL static typing engine

* seekdb error code: 5833

* Error reason: The new engine does not support this feature.

* Solution: No action is required. The SQL engine will automatically retry.

## ERROR 5834 (HY000) : name is already used by an existing object

* seekdb error code: 5834

* Error reason: The object already exists.

* Solution: Do not re-create an object that already exists in the PL environment.

## ERROR 5835 (HY000) : connection description for remote database not found

* seekdb error code: 5835

* Error reason: The connection description for the remote database is not found.

## ERROR 5836 (HY000) : database link not found

* seekdb error code: 5836

* Error reason: The database link to be deleted is not found in the dictionary.

* Solution: Correct the database link name.

## ERROR 5837 (HY000) : Reference to uninitialized composite

* seekdb error code: 5837

* Error reason: The left side references an object, `LOB`, or other composite partition, but the object, `LOB`, or other composite partition is not initialized.

* Solution: Initialize the composite partition by using an appropriate constructor or by assigning the entire object.

## ERROR 5838 (HY000) : Reference to uninitialized collection

* seekdb error code: 5838

* Error reason: The nested table or `Varray` element or `Member` function is referenced, but the collection is not initialized.

* Solution: Initialize the collection by using an appropriate constructor or by assigning the entire object.

## ERROR 5839 (HY000) : no more rows needed

* seekdb error code: 5839

* Error reason: The caller of the pipelined function does not need more rows generated by the pipelined function.

* Solution: Do not catch the `NO_DATA_NEEDED` exception in an exception handling block.

## ERROR 5840 (HY000) : PL/SQL: program error

* seekdb error code: 5840

* Error reason: This is an internal error message. An error is detected in the PL program.

* Solution: This is an internal error code. Contact technical support for assistance.

## ERROR 5841 (HY000) : PL/SQL: Return types of Result Set variables or query do not match

* seekdb error code: 5841

* Error reason: The number of columns or the column types in the query do not match the return types declared for the result set variables, or the types declared for the two result set variables do not match.

* Solution: Modify the program statement or declaration.

## ERROR 5842 (HY000) : PL/SQL: storage error

* seekdb error code: 5842

* Cause: PL/SQL cannot allocate additional storage. This error can be caused by runaway programs.

* Solution:

  1. Ensure that the PL/SQL program does not have memory issues or errors.

  2. Release unused objects by programming, such as setting them to `NULL`.

  3. Increase the available shared or process memory, if applicable.

## ERROR 5843 (HY000) : Subscript outside of limit

* seekdb error code: 5843

* Cause: The subscript is greater than the limit of the `VARRAY`, or the subscript is a non-positive value for the `VARRAY` or nested table.

* Solution: Check the program logic and, if necessary, increase the limit of the `VARRAY`.

## ERROR 5844 (HY000) : invalid cursor

* seekdb error code: 5844

* Cause: The cursor is invalid.

## ERROR 5845 (HY000) : invalid username/password; logon denied

* seekdb error code: 5845

* Cause: The username or password is invalid, and the login is denied.

## ERROR 5846 (HY000) : not logged on

* seekdb error code: 5846

* Cause: The user is not logged on.

## ERROR 5847 (HY000) : method dispatch on NULL SELF argument is disallowed

* seekdb error code: 5847

* Cause: A `Member` method is called with a `NULL SELF` argument.

* Solution: Change the method call type to pass a valid `SELF` argument.

## ERROR 5848 (HY000) : timeout occurred while waiting for a resource

* seekdb error code: 5848

* Cause: Usually due to a dead instance.

* Solution: Check for dead or unrecovered instances. If any, recover them.

## ERROR 5849 (HY000) : column to be modified to NOT NULL is already NOT NULL

* seekdb error code: 5849

* Cause: The column to be modified to `NOT NULL` is already `NOT NULL`.

## ERROR 5850 (HY000) : column to be modified to NULL cannot be modified to NULL

* seekdb error code: 5850

* Cause: The column may allow `NULL` values, and the `NOT NULL` constraint is part of the primary key or `CHECK` constraint.

* Solution: If the primary key or `CHECK` constraint enforces the `NOT NULL` constraint, remove the constraint.

## ERROR 5851 (HY000) :cannot enable (%.\*s.%.\*s) - null values found

* seekdb error code: 5851

* Cause: The enable constraint operation on the table failed because some values in the table do not meet the constraint.

## ERROR 5852 (HY000) : Argument should be a constant

* seekdb error code: 5852

* Cause: The argument should be a constant.

## ERROR 5853 (HY000) : not a single-group group function

* seekdb error code: 5853

* Cause: It is not a single-group `Group` function.

## ERROR 5854 (HY000) : illegal zero-length identifier

* seekdb error code: 5854

* Cause: The zero-length identifier is illegal.

## ERROR 5855 (HY000) : parameter cannot be modified because specified value is invalid

* seekdb error code: 5855

* Cause: The initialization parameter can be modified, but the modified value is invalid.

* Solution: Refer to the seekdb documentation for the valid values of this parameter.

## ERROR 5856 (HY000) : DBMS_SQL access denied

* seekdb error code: 5856

* Cause: Access to `DBMS_SQL` is denied for security reasons.

* Solution: Try to obtain more information from the Alert log and Trace file.

## ERROR 5857 (HY000) : not all variables bound

* seekdb error code: 5857

* Cause: Some variables are not configured.

## ERROR 5859 (HY000) : column is referenced in a multi-column constraint

* seekdb error code: 5859

* Cause: An attempt is made to drop a column that is referenced by a constraint.

* Solution: Drop all constraints that reference the column or specify `CASCADE CONSTRAINTS` in the statement.

## ERROR 5860 (HY000) : cannot modify column datatype with current constraint(s)

* seekdb error code: 5860

* SQLSTATE: HY000

* Cause: An attempt is made to modify the data type of a column with a `CHECK` constraint. However, a column with a `CHECK` constraint can only have its data type changed from `CHAR` to `VARCHAR`.

* Solution: Drop the constraint or do not perform the invalid operation.

## ERROR 5861 (HY000) : The percentile value should be a number between 0 and 1

* seekdb error code: 5861

* Cause: The percentile value specified for the `PERCENTILE_CONT` or `PERCENTILE_DISC` function is out of the valid range.

* Solution: Specify a value in the range [0,1].

## ERROR 5862 (HY000) : The argument should be of numeric or date/datetime type

* seekdb error code: 5862

* Cause: The argument should be of numeric or date/datetime type.

## ERROR 5863 (HY000) : ALTER TABLE\|INDEX RENAME may not be combined with other operations

* seekdb error code: 5863

* Cause: The `ALTER TABLE` or `ALTER INDEX` statement attempts to combine the `RENAME` operation with other operations, which is invalid.

* Solution: Ensure that the `ALTER TABLE` or `ALTER INDEX` statement contains only the `RENAME` operation.

## ERROR 5864 (HY000) : only simple column names allowed here

* seekdb error code: 5864

* Cause: Only simple column names are allowed here.

## ERROR 5866 (HY000) : cannot specify \<(sub)partition-description\> clause in CREATE TABLE or CREATE INDEX)

* seekdb error code: 5866

* Cause: An attempt is made to generate a default partition description (possibly through `PARTITIONS number-of-partitions`) while specifying the `<(sub)partition-description>` clause, which is invalid.

* Solution: Remove one of the invalid clauses.

## ERROR 5867 (HY000) :Duplicate partition name %.\*s

* SeekDB error code: 5867

* Cause: The names of the secondary partitions or subindexes are not unique.

* Resolution: Rename the subpartition to ensure its name is unique in the subpartitions created in the table or index.

## ERROR 5868 (HY000) : Incorrect usage of UPDATE and ORDER BY

* seekdb error code: 5868

* Cause: You cannot use the `ORDER BY` clause for an `UPDATE` statement that updates multiple tables. * Solution: Do not use the `ORDER BY` clause.

* Solution: Remove the `ORDER BY` clause.

## ERROR 5869 (HY000) : Incorrect usage of UPDATE and LIMIT

* seekdb error code: 5869

* Error: You cannot use `LIMIT` when you perform a multi-table `UPDATE`.

* Solution: Remove the `LIMIT` clause.

## ERROR 5870 (HY000) : rowid type mismatch, expect %.\*s, got %.\*s

* seekdb error code: 5870

* Error: The error code is an internal error code.

* Resolution: Contact Technical Support for assistance.

## ERROR 5871 (HY000) : rowid num mismatch, expect %ld, actual %ld

seekdb error code:5871

* Cause: An internal error code.

* Solution: Contact technical support for assistance.

## ERROR 5872 (HY000) :must name %.\*s with a column alias

* seekdb error code: 5872

* SQLSTATE：HY000

* The reason for the error: you must use a column alias to name this expression.

## ERROR 5873 (HY000) : the numeric value does not match the length of the format item

* seekdb error code: 5873

* Cause: The number of digits must match those specified in the FX or FM format code. For example, the `9` does not match the DD format specification, but `09` does.

* Resolution: Enter a valid date or set the FX and FM format specifiers in the format string.

## ERROR 5874 (HY000) : invalid datatype

* seekdb error code: 5874

* Cause: Invalid data type.

## ERROR 5875 (HY000) : table is not partitioned by composite partition method

* seekdb error code: 5875

* Cause: A subpartition maintenance operation is performed on a table that is not partitioned by subpartition.

* Solution: Check whether the table is a subpartitioned table.

## ERROR 5876 (HY000) : VALUES IN (\<value list\>) cannot be used for Range subpartitioned tables

* seekdb error code: 5876

* Cause: The `VALUES (value list)` clause is used for a RANGE subpartitioned table.

* Solution: Use the `VALUES LESS THAN` or `AT` clause with a range partitioned table.

## ERROR 5877 (HY000) : VALUES IN (\<value list\>) clause expected

* seekdb error code: 5877

* The cause of the error: no `VALUES (value list)` clause is specified for the LIST partition.

* Solution: Specify the `VALUES (``value list)` clause.

## ERROR 5879 (HY000) : Expecting VALUES LESS THAN or AT clause

* seekdb Error Code: 5879

* Error: The `VALUES (value list)` clause can be used only with LIST partitioned tables.

* Solution: Use the `VALUES LESS THAN` clause with the RANGE partitioned table.

## ERROR 5880 (HY000) : procedure, function, package, or package body does not exist

seekdb error code: 5880

* Cause: Attempting to access a procedure, function, package, or package body that does not exist.

* Solution: Make sure that the name of the object to be accessed is correct.

## ERROR 5882 (HY000) : invalid time limit specified

* seekdb error code: 5882

* Cause: The parameter time specified for the `dbms_lock.sleep(time)` package is a non-positive value.

* Solution: Specify a positive value.

## ERROR 5883 (HY000) : ## ERROR(s) in array DML

* seekdb Error Code: 5883

* Error reason: Some rows fail in a DML statement.

*Solutions: Check the error stack at the exception capture stage to obtain the specific exception.

## ERROR 5884 (42000) : %s \\'%.\*s.%.\*s\\' compile error

* seekdb error code: 5884

* Cause: The DDL statement used to create the trigger is incorrect.

* Solution: Make modifications to the DDL statement and reexecute it.

## ERROR 5887 (HY000) : missing or invalid password(s)

* seekdb error code: 5887

* Cause: The password is incorrect.

* Solution: Ensure that the correct password is entered, and then try again.

## ERROR 5889 (HY000) : no matching unique or primary key for this column-list

* seekdb error code: 5889

* Error cause: The column list provided in the `REFERENCES` clause of a `CREATE TABLE` or `ALTER TABLE` statement does not match the unique or primary key constraint in the referenced table.

* Resolution: You can query the `ALL_CONS_COLUMNS` view to find the correct column name.

## ERROR 5890 (HY000) : duplicate referential constraint specifications

* seekdb error code: 5890

* The error is generated because multiple foreign key constraints have the same set of referenced columns and referencing columns when you create a table.

* Fix: Modify the `CREATE TABLE` statement to ensure that a table does not contain multiple foreign key constraints where the referenced columns and the referencing columns are the same.

## ERROR 5891 (HY000) : such a referential constraint already exists in the table

* seekdb error code: 5891

* Error reason: When you modify a table, multiple foreign key constraints are defined on the table. The referencing column and the referenced column are the same.

* Solution: Modify the `ALTER TABLE` statement to ensure that no multiple foreign keys in a table can have the same combination of reference and referenced columns.

## ERROR 5893 (HY000) : specified data type is not supported for a virtual column

* seekdb Error 5893:

* Cause: The data type of the generated column is not supported. The data type must not be a `LOB` type.

* Solution: Change the data type of the generated column.

## ERROR 5894 (HY000) : referenced table does not have a primary key

* seekdb error code: 5894

* Error reason: No primary key exists in the referenced table when no foreign key referencing column is specified.

* Solution: Create a primary key or a unique index in the referenced column before you create a foreign key.

## ERROR 5895 (HY000) : data type or length of a table partitioning column may not be changed

* seekdb error code: 5895

* Error reason: The data type and length of a partitioning column cannot be changed.

## ERROR 5896 (HY000) : data type or length of a table partitioning column may not be changed

* seekdb error code: 5896

* Error reason: The data type and length of a subpartitioning column cannot be changed.

## ERROR 5897 (HY000) : cannot decrease column length because some value is too big

* seekdb error code: 5897

* Error reason: The maximum length limit of a column cannot be decreased.

## ERROR 5898 (HY000) : Datetime/Interval internal error

* seekdb error code: 5898

* Error reason: Internal error.

* Solution: Contact technical support for assistance.

## ERROR 5899 (HY000) : partition extended table name cannot refer to a remote object

* seekdb error code: 5899

* Error reason: An extended partition table is used to name a remote object.

* Solution: Correct the expression and retry.

## ERROR 5901 ( HY000 ) : a view is not appropriate here

* seekdb error code: 5901

* Error reason: `EDITIONING_VIEW` is defined on a view.

* Solution: `EDITIONING_VIEW` can be created only on a base table.

## ERROR 5902 (HY000) : cannot select ROWID from,or sample, a join view without a key-preserved table

* seekdb error code: 5902

* Error reason: `ROWID` cannot be queried from a join view or sample without a key-preserved table.

## ERROR 5903 (HY000) : cannot select ROWID from, or sample, a view with DISTINCT, GROUP BY, etc

* seekdb error code: 5903

* Error reason: `ROWID` cannot be queried from a view with `DISTINCT` or `GROUP BY`.

## ERROR 5904 (HY000) : table must have at least 1 column that is not virtual

* seekdb error code: 5904

* Error reason: A table that contains only virtual columns is created.

* Solution: At least one nonvirtual column must be included in the table to be created.

## ERROR 5905 (HY000) : only pure functions can be indexed

* seekdb error code: 5905

* Error reason: The index function uses `SYSDATE` or the user environment.

* Solution: PL functions must be pure functions (`RNDS`, `RNPS`, `WNDS`, and `WNPS`).

## ERROR 5906 (HY000) : only pure functions can be specified in a virtual column expression

* seekdb error code: 5906

* Error reason: The virtual column expression contains a function that returns an uncertain value.

* Solution: Rewrite the expression to reference only pure functions.

## ERROR 5907 (HY000) : UPDATE operation disallowed on virtual columns

* seekdb error code: 5907

* Error reason: The value of a virtual column is updated.

* Solution: Execute the statement without setting the value of the virtual column.

## ERROR 5908 (HY000) : Invalid column expression was specified

* seekdb error code: 5908

* Error reason: The virtual column expression is not a valid arithmetic expression. It may reference another column in the table.

* Solution: Change the expression of the virtual column.

## ERROR 5909 (HY000) : table can have only one identity column

* seekdb error code: 5909

* Error reason: Multiple identity columns are specified for a table.

* Solution: Specify only one identity column for each table.

## ERROR 5910 (HY000) : invalid NOT NULL constraint specified on an identity column

* seekdb error code: 5910

* Error reason: The `NOT NULL` constraint is not correctly specified for an identity column.

* Solution: If the `NOT NULL` constraint is specified for an identity column, it must be enabled and cannot be deferred.

## ERROR 5911 (HY000) : cannot modify NOT NULL constraint on an identity column）

* seekdb error code: 5911

* Error reason: The `NOT NULL` constraint of an identity column is modified.

* Solution: Do not modify the `NOT NULL` constraint of an identity column.

## ERROR 5912 (HY000) : cannot drop NOT NULL constraint on an identity column

* seekdb error code: 5912

* Error reason: The `NOT NULL` constraint of an identity column is dropped.

* Solution: Do not drop the `NOT NULL` constraint of an identity column. The only way to drop the constraint is to use the `DROP IDENTITY` option of `ALTER TABLE MODIFY` to drop the `identity` attribute of the column.

## ERROR 5913 (HY000) : column to be modified is not an identity column

* seekdb error code: 5913

* Error reason: The identity attribute is modified for a column that is not an identity column.

* Solution: Modify the identity attribute of an identity column.

## ERROR 5914 (HY000) : identity column cannot have a default value

* seekdb error code: 5914

* Error reason: A default value is added to an identity column.

* Solution: A default value cannot be specified for an identity column.

## ERROR 5915 (HY000) : identity column must be a numeric type

* seekdb error code: 5915

* Error reason: The value of an identity column is changed to a nonnumeric data type.

* Solution: Do not assign a nonnumeric data type to an identity column.

## ERROR 5916 (HY000) : prebuilt table managed column cannot be an identity column

* seekdb error code: 5916

* Error reason: An instance view is created on a prebuilt table with an identity column.

* Solution: Either remove the `identity` attribute or remove the identity column from the instance view definition.

## ERROR 5917 (HY000) : cannot alter a system-generated sequence

* seekdb error code: 5917

* Error reason: A system-generated sequence is modified.

* Solution: System-generated sequences, such as those created for identity columns, cannot be modified.

## ERROR 5918 (HY000) : cannot drop a system-generated sequence

* seekdb error code: 5918

* Error reason: You tried to drop a system-generated sequence.

* Solution: You cannot drop a system-generated sequence, such as a sequence created for an identity column.

## ERROR 5919 (HY000)：cannot insert into a generated always identity column

* seekdb error code: 5919

* Error reason: You tried to insert a value into an identity column created by using the `GENERATED ALWAYS` keyword.

* Solution: You cannot directly insert a value into an identity column created by using the `GENERATED ALWAYS` keyword. Instead, the value is provided by the associated sequence generator.

## ERROR 5920 (HY000) : cannot update a generated always identity column

* seekdb error code: 5920

* Error reason: You tried to update an identity column created by using the `GENERATED ALWAYS` keyword.

* Solution: You cannot directly update an identity column created by using the `GENERATED ALWAYS` keyword.

## ERROR 5921 (HY000) : identity column sequence mismatch in ALTER TABLE EXCHANGE PARTITION

* seekdb error code: 5921

* Error reason: The sequences of the identity columns in the two tables specified in the `EXCHANGE` clause do not increase or decrease.

* Solution: Ensure that the sequences of the identity columns specified with the `INCREMENT BY` clause have the same sign.

## ERROR 5922 (HY000) : cannot rename a system-generated sequence

* seekdb error code: 5922

* Error reason: You tried to rename a system-generated sequence.

* Solution: You cannot rename a system-generated sequence, such as a sequence created for an identity column.

## ERROR 5923 (HY000) : UPDATE/REFERENCES may only be REVOKEd from the whole table, not by column

* seekdb error code: 5923

* Error reason: The `UPDATE` or `REFERENCES` privilege can be revoked only from the entire table, not from individual columns.

## ERROR 5924 (HY000) : not executed, type body '%.\*s' does not exist

* seekdb error code: 5924

* Error reason: You tried to execute a stored program that does not exist.

* Solution: Ensure that you specify the correct name.

## ERROR 5925 (HY000) : The argument \[%s\] of WIDTH_BUCKET function is NULL or invalid

* seekdb error code: 5925

* Error reason: The `[%s]` argument of the `WIDTH_BUCKET` function is `NULL` or invalid.

## ERROR 5926 (HY000) : Not enough memory for CONNECT BY operation

* seekdb error code: 5926

* Error reason: On the new engine, an error is returned when the recursion depth exceeds 2^30. On the old engine, an error is returned when the number of nodes and their child nodes along the path from the root node to the current node exceeds 2^30. This value is fixed and generally not exceeded.

* Solution: Currently, there is no solution. Increasing the memory size does not solve this issue. The only solution is to reduce the recursion depth or decrease the data volume.

## ERROR 5927 (HY000) : illegal parameter in SYS_CONNECT_BY_PATH function

* seekdb error code: 5927

* Error reason: The `SYS_CONNECT_BY_PATH` function contains an invalid parameter.

## ERROR 5928 (HY000) : host %.\*s unknown

* seekdb error code: 5928

* Error reason: The specified host is unknown.

* Solution: Check the spelling of the host name or IP address and ensure that the host name or IP address is valid.

## ERROR 5929 (HY000) : Window name '%.\*s' is not defined

* seekdb error code: 5929

* Error reason: The specified window function does not exist.

* Solution: Confirm that the relevant window function has been created and use the correct window function name.

## ERROR 5930 (HY000) : maximum open cursors exceeded

* seekdb error code: 5930

* Error reason: The number of open cursors exceeds the limit.

* Solution: Close the cursors or adjust the `open_cursors` parameter.

## ERROR 5931 (HY000) : argument is null, invalid, or out of range

* seekdb error code: 5931

* Error reason: The value of the passed parameter is `NULL`, invalid, or out of range. For example, the value of the position or size parameter for `LOB / FILE` is out of the range of 1 to (4GB-1). Or, the file is opened in an invalid mode.

* Solution: Check and correct the program to ensure that you do not pass `NULL`, invalid, or out-of-range parameter values.

## ERROR 5932 (HY000) : unexpected name string

* seekdb error code: 5932

* Error reason: The name string is invalid.

## ERROR 5933 (HY000) : PL/SQL: could not findprogram unit being called: '%.\*s'

* seekdb error code: 5933

* Error reason: The program unit cannot be found.

## ERROR 5934 (HY000) : fetch out of sequence

* seekdb error code: 5934

* SQLSTATE: HY000

* Error reason: You tried to fetch from an invalid cursor. This error can occur in the following situations:

  * You fetched the last row and returned the `OBE-1403` error, and then fetched from the cursor.

  * You opened a cursor by using the `FOR UPDATE` clause, committed, and then fetched from the cursor.

  * You rebind all placeholders in an SQL statement and then fetch from the cursor before reexecuting the statement.

  <main id="notice" type='explain'>
    <h4>Note</h4>
    <p>Implicit fetches in PL/SQL cursor loops can also cause this error.</p>
  </main>

* Solution:

  * Do not issue the `FETCH` statement after you fetched the last row.

  * Do not commit after you opened a cursor by using the `FOR UPDATE` clause and then fetch from the cursor.

  * Execute the SQL statement after rebinding and then fetch from the cursor.

## ERROR 5959 (HY000) : invalid SIZE specified

* seekdb error code: 5959

* Error reason: The specified `SIZE` value of the histogram is out of range.

* Solution: Specify a `SIZE` value in the range of [1, 2048].

## ERROR 5975 (HY000) : \ndblink remote error code: %d,\nremote error msg: %.*s"

* seekdb error code: 5975

* Error reason: An error occurred when connecting to the remote database, and the error code cannot be mapped to a seekdb error code.

* Solution: Find the cause based on the error code in the error message.

## ERROR 5976 (HY000) : can not find the expected version of OCI LIB: %.*s

* seekdb error code: 5976

* Error cause: The expected version of the OCI LIB is not found.

* Solution: For more information, see [Install and configure OCI](https://www.oceanbase.com/docs/common-oceanbase-database-cn-1000000002015397).